@@ -4,7 +4,7 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.17_03';
+  our $VERSION = '0.17_04';
 
   use Zydeco authority => 'cpan:SMONFF', version   => $VERSION;
   use Carp;
@@ -18,17 +18,24 @@ package Art::World {
 
 
   role Buyer {
-    requires money;
-    method acquire ( Num $price ) {
-      say "I bought !";
+    requires money;  # Num $price
+    method acquire ( Artwork $art ) {
+      $self->money( $self->money - $art->value );
+      push @{ $self->collection }, $art;
+      say "I bought for " . $art->value . " worth of art!" ;
     }
 
-    method sale ( Num $price ) {
+    method sale ( Artwork $art ) {
+      $self->money( $self->money + $art->value );
+      # TODO DELETE FROM COLLECTION
+      # Using a grep filtering on the collection by id seems like a good idea
+      # ...
       say "I sold !";
     }
   }
 
 
+  # Dunno how but the fact of being collected should bump artist reputation
   role Collectionable {
     # Should be an object of type Agent
     has owner  ( type => 'ArrayRef[Collector]' );
@@ -194,12 +201,12 @@ package Art::World {
 
 
     class Collector with Active, Buyer {
-      has money! ( type => Num );
-      # Actually an ArrayRef of Artworks
+      has money! ( type => Num, is => rw );
       has collection (
-        type    => ArrayRef[Any, 0, 100],
-        default => sub { [] }
-      ) ;
+        type    => 'ArrayRef[Artwork, 0 ]',
+        default => sub { [] },
+        is      => rw,
+      );
     }
 
     class Critic;
@@ -226,6 +233,11 @@ package Art::World {
       type => ArrayRef[ Object ]
     );
 
+    has title(
+      is => ro,
+      type => Str,
+    );
+
     class Article;
 
     class Artwork with Showable, Collectionable  {
@@ -293,7 +305,7 @@ Role for L<C<Places>|Art::World/"Place"> that display some  L<C<Artworks>|Art::W
 =head2 Fame
 
 C<Fame> role provide ways to control the knowledge and reputation that various
-C<Agents>, C<Places> or C<Works> have.
+C<Agents>, C<Places> or C<Works> have. Cannot be negative.
 
 It has an handy C<bump_fame()> method that self-bump the fame count. It can be
 passed a positive C<Num>, a negative C<Num> (so that the fame will get lower)
@@ -307,6 +319,9 @@ and even no parameter, in that case it will just add 1.
   say $artist->bump_fame;               # ==>  1.42
   say $artist->bump_fame( 0.0042 );     # ==>  1.4242
 
+If you try to update the fame to a negative value, nothing happens and a nice
+warning is displayed.
+
 =head2 Market
 
 It is all about offer and demand. Involve a price but should involve more money
@@ -439,6 +454,8 @@ Nadia Boursin-Piraud
 
 Nicolas Herubel
 
+Pierre Aubert
+
 Seb. Hu-Rillettes
 
 Toby Inkster
